@@ -18,11 +18,11 @@ XML::OPDS - OPDS (Open Publication Distribution System) feed creation
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 DESCRIPTION
@@ -79,8 +79,15 @@ generating valid and usable catalogs.
                             title => 'Titles',
                             description => 'texts sorted by title',
                             href => '/titles',
-                            acquisition => 1,
+
                            );
+  # or, implicitely setting the self rel and cleaning the navigation
+  # stash, keeping the meta
+  $feed->add_to_navigations_new_level(
+                                      title => 'Titles',
+                                      acquisition => 1,
+                                      href => '/titles',
+                                     );
   $feed->add_to_acquisitions(
                              href => '/my/title',
                              title => 'My title',
